@@ -23,7 +23,11 @@ os.environ["TOKENIZERS_PARALLELISM"] = "false"  # to turn off warning message
 PAD_TOKEN_LABEL_ID = torch.nn.CrossEntropyLoss().ignore_index
 
 
-def get_lm(model_name: str, use_auth_token: bool = False, torch_dtype = None):
+def get_lm(model_name: str,
+           use_auth_token: bool = False,
+           torch_dtype=None,
+           device_map: str = None,
+           low_cpu_mem_usage: bool = False):
     """ get encoder-decoder lms from huggingface """
     # tokenizer
     local_files_only = not internet_connection()
@@ -47,13 +51,12 @@ def get_lm(model_name: str, use_auth_token: bool = False, torch_dtype = None):
         model_class = transformers.SwitchTransformersForConditionalGeneration.from_pretrained
     else:
         raise ValueError(f'unsupported model type: {config.model_type}')
-    if torch_dtype is None:
-        model = model_class(
-            model_name, config=config, local_files_only=local_files_only, use_auth_token=use_auth_token)
-    else:
-        model = model_class(
-            model_name, config=config, local_files_only=local_files_only, use_auth_token=use_auth_token, torch_dtype=torch_dtype)
-    # add new special tokens to the tokenizer and the model if they don't have it
+    param = {'config': config, "local_files_only": local_files_only, "use_auth_token": use_auth_token, "low_cpu_mem_usage": low_cpu_mem_usage}
+    if torch_dtype is not None:
+        param['torch_dtype'] = torch_dtype
+    if device_map is not None:
+        param['device_map'] = device_map
+    model = model_class(model_name, **param)
     return tokenizer, model, config
 
 
@@ -67,7 +70,9 @@ class EncoderDecoderLM:
                  max_length_decoder: int = None,
                  device: str = None,
                  num_gpus: int = None,
-                 torch_dtype=None):
+                 torch_dtype=None,
+                 device_map: str = None,
+                 low_cpu_mem_usage: bool = False):
         """ Encoder-Decoder Language Model.
 
         @param model: Model alias or path to local model file.
@@ -78,7 +83,9 @@ class EncoderDecoderLM:
         logging.info(f'Loading Model: `{model}`')
 
         # load model
-        self.tokenizer, self.model, self.config = get_lm(model, use_auth_token=use_auth_token)
+        self.tokenizer, self.model, self.config = get_lm(
+            model, use_auth_token=use_auth_token, torch_dtype=torch_dtype, device_map=device_map,
+            low_cpu_mem_usage=low_cpu_mem_usage)
         if self.tokenizer.pad_token is None:
             self.tokenizer.pad_token = "<<PAD>>"
         if max_length_encoder is None:
